@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2018 Carlos Donizete Froes [a.k.a coringao]
  *
  * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
@@ -102,7 +102,9 @@ OsmoseCore::OsmoseCore(const char *rom_f,  unsigned int *output, OsmoseConfigura
     {
 		try
 		{
-			sndThread = new SoundThread("plughw:0,0", p->getFIFOSoundBuffer());
+		        // The plugdev device is obsolete. Replacing it by "default" made it working with pulseaudio.
+		        // Contributed by: Kevin Joly (Kev-J)
+			sndThread = new SoundThread("default", p->getFIFOSoundBuffer());
 			sndThread->start(); 	// Start thread, not playing !
 			string msg = "Creating SoundThread";
 			QLogWindow::getInstance()->appendLog(msg);
