@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2018 Carlos Donizete Froes [a.k.a coringao]
  *
  * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
@@ -26,8 +26,21 @@
 #include <QTextStream>
 #include "OsmoseGUI.h"
 
+// GNOME3 on Debian has XDG_SESSION_TYPE, which Qt warns about at startup:
+//
+//      Warning: Ignoring XDG_SESSION_TYPE=wayland on Gnome.
+//      Use QT_QPA_PLATFORM=wayland to run on Wayland anyway.
+//
+// In this case, the warning is muted. This hack will be retained here until a
+// future version of Qt provides Qt Wayland widgets that are usable
+// in the gnome shell. Cf. https://bugreports.qt.io/browse/QTBUG-68619
+    
 int main(int argc, char *argv[])
 {
+    if (qgetenv("XDG_SESSION_TYPE") == QByteArrayLiteral("wayland")) {
+        qunsetenv("XDG_SESSION_TYPE");
+        qEnvironmentVariable("QT_QPA_PLATFORM", "wayland");
+    }
     QApplication app(argc, argv);
     OsmoseGUI window;
     window.resize(512, 384 + MENU_HEIGHT);
